@@ -71,17 +71,19 @@ class PowerAsset(Asset):
         """Shortcut for finding the associated Analogs (via it's terminals)"""
         return self.terminals().analogs()
 
-    def time_series(self, measurement_type: str = None, timeseries_type: str = None, **kwargs):
+    def time_series(
+        self, measurement_type: Union[str, List[str]] = None, timeseries_type: Union[str, List[str]] = None, **kwargs
+    ):
         """Retrieves the time series in the asset subtree.
 
         Args:
-            measurement_type: Type of measurement, e.g. ThreePhaseActivePower
-            timeseries_type: Type of time series, e.g. estimated_value
+            measurement_type: Type of measurement, e.g. "ThreePhaseActivePower", or list thereof
+            timeseries_type: Type of time series, e.g. "estimated_value", or list thereof
             kwargs: Other metadata filters
         """
-        metadata_filter = {"measurement_type": measurement_type, "timeseries_type": timeseries_type, **kwargs}
-        metadata_filter = {k: v for k, v in metadata_filter.items() if v}
-        return self._cognite_client.time_series.list(asset_subtree_ids=[self.id], metadata=metadata_filter, limit=None)
+        return PowerAssetList([self], cognite_client=self._cognite_client).time_series(
+            measurement_type=measurement_type, timeseries_type=timeseries_type, **kwargs
+        )
 
     @staticmethod
     def _load_from_asset(asset, class_name, cognite_client):
@@ -279,8 +281,8 @@ class Substation(PowerAsset):
         """Shortcut for finding the connected ACLineSegments for a substation"""
         return self.terminals().ac_line_segments(base_voltage=base_voltage, grid_type=grid_type)
 
-    def busbar_sections(self):
-        return self.relationship_sources("BusbarSection")
+    def busbar_sections(self, base_voltage: Iterable = None):
+        return self.relationship_sources("BusbarSection", base_voltage=base_voltage)
 
     def conform_loads(self):
         return self.relationship_sources("ConformLoad")
@@ -594,10 +596,10 @@ class PowerAssetList(AssetList):
             PowerAssetList: list of connected assets
         """
         if _sources and _targets:
-            raise ArgumentError("Can not combine _sources and _targets.")
+            raise ValueError("Can not combine _sources and _targets.")
         if not _sources and not _targets:
             return PowerAssetList([], cognite_client=self._cognite_client)
-        rels = self._cognite_client.relationships.list(
+        rels = self._cognite_client.relationships_playground.list(
             sources=_sources, targets=_targets, relationship_type=relationship_type, limit=None
         )
         if _sources:
@@ -803,21 +805,36 @@ class PowerAssetList(AssetList):
         else:
             raise WrongPowerTypeError(f"Can't get opposite ends for a list of {self.type}")
 
-    def time_series(self, measurement_type=None, timeseries_type=None, **kwargs) -> TimeSeriesList:
+    def time_series(
+        self, measurement_type: Union[str, List[str]] = None, timeseries_type: Union[str, List[str]] = None, **kwargs
+    ) -> TimeSeriesList:
         """Retrieves the time series in the asset subtrees.
 
         Args:
-            measurement_type: Type of measurement, e.g. ThreePhaseActivePower
-            timeseries_type: Type of time series, e.g. estimated_value
+            measurement_type: Type of measurement, e.g. "ThreePhaseActivePower", or list thereof
+            timeseries_type: Type of time series, e.g. "estimated_value", or list thereof
             kwargs: Other metadata filters"""
-        metadata_filter = {"measurement_type": measurement_type, "timeseries_type": timeseries_type, **kwargs}
-        metadata_filter = {k: v for k, v in metadata_filter.items() if v}
-        chunk_size = 100
-        ids = [a.id for a in self.data]
-        tasks = [
-            {"asset_subtree_ids": ids[i : i + self._retrieve_chunk_size], "metadata": metadata_filter, "limit": None}
-            for i in range(0, len(ids), chunk_size)
-        ]
+        if isinstance(measurement_type, str):
+            measurement_type = [measurement_type]
+        if isinstance(timeseries_type, str):
+            timeseries_type = [timeseries_type]
+        tasks = []
+        for ts_type in timeseries_type or [None]:
+            for mt_type in measurement_type or [None]:
+                metadata_filter = {"measurement_type": mt_type, "timeseries_type": ts_type, **kwargs}
+                metadata_filter = {k: v for k, v in metadata_filter.items() if v}
+                chunk_size = 100
+                ids = [a.id for a in self.data]
+                tasks.extend(
+                    [
+                        {
+                            "asset_subtree_ids": ids[i : i + self._retrieve_chunk_size],
+                            "metadata": metadata_filter,
+                            "limit": None,
+                        }
+                        for i in range(0, len(ids), chunk_size)
+                    ]
+                )
         res_list = execute_tasks_concurrently(self._cognite_client.time_series.list, tasks, max_workers=10)
         return TimeSeriesList(sum(res_list.joined_results(), []))
 
